@@ -40,23 +40,27 @@
 #endif
 #endif
 
-#include "games-card.h"
 #include "games-runtime.h"
 
 #include "games-files.h"
 
 G_DEFINE_TYPE (GamesFileList, games_file_list, G_TYPE_OBJECT)
 
+struct GamesFileListPrivate
+{
+  GList *list;
+};
+
 /* Remove duplicate names form the list */
-     static void
-       games_file_list_remove_duplicates (GamesFileList * filelist)
+static void
+games_file_list_remove_duplicates (GamesFileList * filelist)
 {
   GList *l;
 
   if (filelist == NULL)
     return;
 
-  l = filelist->list;
+  l = filelist->priv->list;
 
   if ((l == NULL) || (l->next == NULL))
     return;
@@ -124,11 +128,11 @@ games_file_list_new (const gchar * glob, ...)
   filelist = g_object_new (GAMES_FILE_LIST_TYPE, NULL);
 
   va_start (paths, glob);
-  filelist->list = games_file_list_new_internal (glob, paths);
+  filelist->priv->list = games_file_list_new_internal (glob, paths);
   va_end (paths);
 
-  filelist->list =
-    g_list_sort (filelist->list, (GCompareFunc) g_utf8_collate);
+  filelist->priv->list =
+    g_list_sort (filelist->priv->list, (GCompareFunc) g_utf8_collate);
   games_file_list_remove_duplicates (filelist);
 
   return filelist;
@@ -138,7 +142,7 @@ games_file_list_new (const gchar * glob, ...)
 void
 games_file_list_transform_basename (GamesFileList * filelist)
 {
-  GList *current = filelist->list;
+  GList *current = filelist->priv->list;
   gchar *shortname;
 
   while (current) {
@@ -206,7 +210,7 @@ games_image_suffix_list_init (void)
 }
 
 static GList *
-games_file_list_new_images_single (gchar * directory)
+games_file_list_new_images_single (const gchar * directory)
 {
   GDir *dir;
   GList *list = NULL;
@@ -254,7 +258,7 @@ games_file_list_new_images_single (gchar * directory)
  * Return value: A new GamesFileList containing the list of image files.
  **/
 GamesFileList *
-games_file_list_new_images (gchar * path1, ...)
+games_file_list_new_images (const gchar * path1, ...)
 {
   GamesFileList *filelist;
   GList *list;
@@ -263,16 +267,16 @@ games_file_list_new_images (gchar * path1, ...)
 
   filelist = g_object_new (GAMES_FILE_LIST_TYPE, NULL);
 
-  filelist->list = games_file_list_new_images_single (path1);
+  filelist->priv->list = games_file_list_new_images_single (path1);
   va_start (paths, path1);
   while ((pathentry = va_arg (paths, gchar *)) != NULL) {
-    list = g_list_concat (filelist->list,
+    list = g_list_concat (filelist->priv->list,
 			  games_file_list_new_images_single (pathentry));
   }
   va_end (paths);
 
-  filelist->list =
-    g_list_sort (filelist->list, (GCompareFunc) g_utf8_collate);
+  filelist->priv->list =
+    g_list_sort (filelist->priv->list, (GCompareFunc) g_utf8_collate);
   games_file_list_remove_duplicates (filelist);
 
   return filelist;
@@ -280,7 +284,7 @@ games_file_list_new_images (gchar * path1, ...)
 
 /**
  * games_file_list_create_widget:
- * @gamesfilelist: The list of files to use.
+ * @filelist: The list of files to use.
  * @selection: The name to select as the default. NULL means no default.
  * @flags: A set of flags to specify how the names are displayed. 
  * 
@@ -291,25 +295,25 @@ games_file_list_new_images (gchar * path1, ...)
  * removes extensions, and GAMES_FILE_LIST_REPLACE_UNDERSCORES with replaces
  * underscores with spaces.
  * 
- * Return value: A widget with the list of names.
+ * Return value: (transfer full): A widget with the list of names.
  **/
 GtkWidget *
-games_file_list_create_widget (GamesFileList * gamesfilelist,
+games_file_list_create_widget (GamesFileList * filelist,
 			       const gchar * selection, guint flags)
 {
   gint itemno;
   GtkComboBox *widget;
   gchar *visible, *string;
-  GList *filelist = gamesfilelist->list;
+  GList *iter = filelist->priv->list;
   gboolean found = FALSE;
 
-  widget = GTK_COMBO_BOX (gtk_combo_box_new_text ());
+  widget = GTK_COMBO_BOX (gtk_combo_box_text_new ());
 
   itemno = 0;
-  while (filelist) {
+  while (iter) {
     gchar *s;
 
-    string = (gchar *) filelist->data;
+    string = (gchar *) iter->data;
     visible = g_strdup (string);
 
     /* These are a bit hackish, but we don't yet have a good regexp
@@ -329,7 +333,7 @@ games_file_list_create_widget (GamesFileList * gamesfilelist,
       }
     }
 
-    gtk_combo_box_append_text (widget, visible);
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), visible);
     if (selection && (!strcmp (string, selection))) {
       gtk_combo_box_set_active (widget, itemno);
       found = TRUE;
@@ -338,7 +342,7 @@ games_file_list_create_widget (GamesFileList * gamesfilelist,
     g_free (visible);
 
     itemno++;
-    filelist = g_list_next (filelist);
+    iter = g_list_next (iter);
   }
   if (!found)
     gtk_combo_box_set_active (widget, 0);
@@ -349,28 +353,28 @@ games_file_list_create_widget (GamesFileList * gamesfilelist,
 /**
  * games_file_list_for_each:
  * @filelist: The file list to iterate over.
- * @function: The function to call on each item. It gets called with two 
+ * @function: (scope call): The function to call on each item. It gets called with two 
  * arguments: the file name and the pointer supplied to this function in 
  * the userdata argument.
- * @userdata: An arbitrary pointer that gets passed as the second argument
+ * @userdata: (closure): An arbitrary pointer that gets passed as the second argument
  * to each call of function.
  * 
  * Apply a function to each file name in the list.
  **/
 void
 games_file_list_for_each (GamesFileList * filelist, GFunc function,
-			  gpointer userdata)
+                          gpointer userdata)
 {
-  g_list_foreach (filelist->list, function, userdata);
+  g_list_foreach (filelist->priv->list, function, userdata);
 }
 
 /**
  * games_file_list_find:
  * @filelist: The file list to iterate over.
- * @function: The function to call on each item. It gets called with two 
+ * @function: (scope call): The function to call on each item. It gets called with two 
  * arguments: the file name and the pointer supplied to this function in 
  * the userdata argument.
- * @userdata: An arbitrary pointer that gets passed as the second argument
+ * @userdata: (closure): An arbitrary pointer that gets passed as the second argument
  * to each call of function.
  * 
  * Find a file name by iterating through a list until the given function
@@ -385,7 +389,7 @@ games_file_list_find (GamesFileList * filelist, GCompareFunc function,
 {
   GList *element;
 
-  element = g_list_find_custom (filelist->list, userdata, function);
+  element = g_list_find_custom (filelist->priv->list, userdata, function);
 
   return element ? g_strdup ((gchar *) element->data) : NULL;
 }
@@ -403,7 +407,7 @@ games_file_list_find (GamesFileList * filelist, GCompareFunc function,
 gchar *
 games_file_list_get_nth (GamesFileList * filelist, gint n)
 {
-  return (gchar *) g_list_nth_data (filelist->list, n);
+  return (gchar *) g_list_nth_data (filelist->priv->list, n);
 }
 
 static void
@@ -414,8 +418,8 @@ games_file_list_finalize (GObject * object)
   /* For simplicity we haven't used the dispose method since we can
    * guarantee that everything this references doesn't reference itself. */
 
-  g_list_foreach (filelist->list, (GFunc) g_free, NULL);
-  g_list_free (filelist->list);
+  g_list_foreach (filelist->priv->list, (GFunc) g_free, NULL);
+  g_list_free (filelist->priv->list);
 
   G_OBJECT_CLASS (games_file_list_parent_class)->finalize (object);
 }
@@ -426,55 +430,12 @@ games_file_list_class_init (GamesFileListClass * class)
   GObjectClass *oclass = G_OBJECT_CLASS (class);
 
   oclass->finalize = games_file_list_finalize;
+
+  g_type_class_add_private (oclass, sizeof (GamesFileListPrivate));
 }
 
 static void
 games_file_list_init (GamesFileList * filelist)
 {
-}
-
-/**
- * games_file_list_card_themes:
- * @scalable: whether to look for scalable or prerendered themes
- *
- * Note that the returned #GamesFileList's list contains the found
- * theme names in the filename encoding!
- * 
- * Returns: a new #GamesFileList containing the found themes
- */
-GamesFileList *
-games_file_list_card_themes (gboolean scalable)
-{
-  GamesFileList *files;
-  GList *l;
-  GamesRuntimeDirectory dir;
-  const char *glob, *path;
-
-#ifdef HAVE_RSVG
-  if (scalable) {
-    glob = "*.svg";
-    dir = GAMES_RUNTIME_SCALABLE_CARDS_DIRECTORY;
-  } else
-#endif /* HAVE_RSVG */
-  {
-    glob = "*.card-theme";
-    dir = GAMES_RUNTIME_PRERENDERED_CARDS_DIRECTORY;
-  }
-
-  path = games_runtime_get_directory (dir);
-  files = games_file_list_new (glob, path, NULL);
-
-  games_file_list_transform_basename (files);
-
-  for (l = files->list; l != NULL; l = l->next) {
-    const char *filename = (const char *) l->data;
-    char *dot;
-
-    dot = strrchr (filename, '.');
-    if (dot) {
-      *dot = '\0';
-    }
-  }
-
-  return files;
+  filelist->priv = G_TYPE_INSTANCE_GET_PRIVATE (filelist, GAMES_FILE_LIST_TYPE, GamesFileListPrivate);
 }
